@@ -1,4 +1,4 @@
 from .api import dataclass_json
 from .api import JSONMixin
 
-__all__ = ('dataclass_json', 'JSONMixin',)
+__all__ = ['dataclass_json', 'JSONMixin']
